
#ifndef GRANTLEETHEME_EXPORT_H
#define GRANTLEETHEME_EXPORT_H

#ifdef GRANTLEETHEME_STATIC_DEFINE
#  define GRANTLEETHEME_EXPORT
#  define GRANTLEETHEME_NO_EXPORT
#else
#  ifndef GRANTLEETHEME_EXPORT
#    ifdef KPim6GrantleeTheme_EXPORTS
        /* We are building this library */
#      define GRANTLEETHEME_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define GRANTLEETHEME_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef GRANTLEETHEME_NO_EXPORT
#    define GRANTLEETHEME_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef GRANTLEETHEME_DECL_DEPRECATED
#  define GRANTLEETHEME_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef GRANTLEETHEME_DECL_DEPRECATED_EXPORT
#  define GRANTLEETHEME_DECL_DEPRECATED_EXPORT GRANTLEETHEME_EXPORT GRANTLEETHEME_DECL_DEPRECATED
#endif

#ifndef GRANTLEETHEME_DECL_DEPRECATED_NO_EXPORT
#  define GRANTLEETHEME_DECL_DEPRECATED_NO_EXPORT GRANTLEETHEME_NO_EXPORT GRANTLEETHEME_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef GRANTLEETHEME_NO_DEPRECATED
#    define GRANTLEETHEME_NO_DEPRECATED
#  endif
#endif
#include <grantleetheme_version.h>

#define GRANTLEETHEME_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(GRANTLEETHEME_NO_DEPRECATED)
#  undef GRANTLEETHEME_DEPRECATED
#  define GRANTLEETHEME_DEPRECATED_EXPORT GRANTLEETHEME_EXPORT
#  define GRANTLEETHEME_DEPRECATED_NO_EXPORT GRANTLEETHEME_NO_EXPORT
#elif defined(GRANTLEETHEME_NO_DEPRECATED_WARNINGS)
#  define GRANTLEETHEME_DEPRECATED
#  define GRANTLEETHEME_DEPRECATED_EXPORT GRANTLEETHEME_EXPORT
#  define GRANTLEETHEME_DEPRECATED_NO_EXPORT GRANTLEETHEME_NO_EXPORT
#else
#  define GRANTLEETHEME_DEPRECATED GRANTLEETHEME_DECL_DEPRECATED
#  define GRANTLEETHEME_DEPRECATED_EXPORT GRANTLEETHEME_DECL_DEPRECATED_EXPORT
#  define GRANTLEETHEME_DEPRECATED_NO_EXPORT GRANTLEETHEME_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define GRANTLEETHEME_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define GRANTLEETHEME_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef GRANTLEETHEME_NO_DEPRECATED
#  define GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT GRANTLEETHEME_VERSION
#endif
#ifdef GRANTLEETHEME_NO_DEPRECATED_WARNINGS
#  define GRANTLEETHEME_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef GRANTLEETHEME_DEPRECATED_WARNINGS_SINCE
#  ifdef GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define GRANTLEETHEME_DEPRECATED_WARNINGS_SINCE GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define GRANTLEETHEME_DEPRECATED_WARNINGS_SINCE GRANTLEETHEME_VERSION
#  endif
#endif

#ifndef GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef GRANTLEETHEME_DEPRECATED
#  define GRANTLEETHEME_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > GRANTLEETHEME_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define GRANTLEETHEME_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* GRANTLEETHEME_EXPORT_H */
